@@ -7,7 +7,7 @@ temp_csv_file <- function(dir = '') {
 test_that('available data is listed correctly with default configuration', {
   # Create temporary project
   test_project <- tempfile('test_project')
-  suppressMessages(create.project(test_project, minimal = FALSE))
+  suppressMessages(create.project(test_project))
   on.exit(unlink(test_project, recursive = TRUE), add = TRUE)
 
   # Set temporary project as working directory
@@ -41,9 +41,9 @@ test_that('available data is listed correctly with default configuration', {
   expect_true("varname" %in% names(data.files))
   expect_true(class(data.files$varname) == "character")
 
-  # Check data.frame has a character variable "reader"
+  # Check data.frame has a list variable "reader"
   expect_true("reader" %in% names(data.files))
-  expect_true(class(data.files$reader) == "character")
+  expect_true(class(data.files$reader) == "list")
 
   # Check data.frame has a logical variable "is_ignored"
   expect_true("is_ignored" %in% names(data.files))
@@ -69,13 +69,15 @@ test_that('available data is listed correctly with default configuration', {
   test.df <- data.frame(
     filename = c(test_file1, 'README.md', 'test'),
     varname = c(gsub('.csv', '', test_file1), "", ""),
-    reader = c('csv.reader', "", ""),
     is_ignored = c(FALSE, FALSE, FALSE),
     is_directory = c(FALSE, FALSE, TRUE),
     is_cached = c(FALSE, FALSE, FALSE),
     cache_only = c(FALSE, FALSE, FALSE),
     stringsAsFactors = FALSE
   )
+
+  test.df$reader <- list('csv.reader', '', '')
+
   # Sort data.frame according to collation of the testing process (for example
   # LC_COLLATE=C and LC_COLLATE=en_US.UTF-8 return different order)
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
@@ -93,7 +95,7 @@ test_that('available data is listed correctly with default configuration', {
 test_that('available data is listed correctly with recursive_loading = TRUE', {
   # Create temporary project
   test_project <- tempfile('test_project')
-  suppressMessages(create.project(test_project, minimal = FALSE))
+  suppressMessages(create.project(test_project))
   on.exit(unlink(test_project, recursive = TRUE), add = TRUE)
 
   # Set temporary project as working directory
@@ -123,13 +125,14 @@ test_that('available data is listed correctly with recursive_loading = TRUE', {
     varname = c(gsub('.csv', '', test_file1),
                 "",
                 gsub('[/\\\\]', '.', gsub('.csv', '', test_file2))),
-    reader = c("csv.reader", "", "csv.reader"),
     is_ignored = c(FALSE, FALSE, FALSE),
     is_directory = c(FALSE, FALSE, FALSE),
     is_cached = c(FALSE, FALSE, FALSE),
     cache_only = c(FALSE, FALSE, FALSE),
     stringsAsFactors = FALSE
   )
+  test.df$reader <- list("csv.reader", "", "csv.reader")
+
   # Sort data.frame according to collation of the testing process (for example
   # LC_COLLATE=C and LC_COLLATE=en_US.UTF-8 return different order)
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
@@ -152,7 +155,7 @@ test_that('available data is listed correctly with recursive_loading = TRUE', {
 test_that('available data is listed correctly with data_ignore', {
   # Create temporary project
   test_project <- tempfile('test_project')
-  suppressMessages(create.project(test_project, minimal = FALSE))
+  suppressMessages(create.project(test_project))
   on.exit(unlink(test_project, recursive = TRUE), add = TRUE)
 
   # Set temporary project as working directory
@@ -221,9 +224,8 @@ test_that('available data is listed correctly with data_ignore', {
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
   test.df <- test.df[sort.df,]
 
-  override.config <- list(data_ignore = '',
-                          recursive_loading = TRUE)
-  expect_error(data.files <- list.data(override.config = override.config), NA)
+  expect_error(data.files <- list.data(data_ignore = '',
+                                       recursive_loading = TRUE), NA)
   expect_true(nrow(data.files) == 4)
   expect_equal(data.files$filename, test.df$filename)
   expect_equal(data.files$is_ignored, test.df$is_ignored)
@@ -248,8 +250,7 @@ test_that('available data is listed correctly with data_ignore', {
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
   test.df <- test.df[sort.df,]
 
-  override.config <- list(data_ignore = '*.csv')
-  expect_error(data.files <- list.data(override.config = override.config), NA)
+  expect_error(data.files <- list.data(data_ignore = '*.csv'), NA)
   expect_true(nrow(data.files) == 4)
   expect_equal(data.files$filename, test.df$filename)
   expect_equal(data.files$is_ignored, test.df$is_ignored)
@@ -277,8 +278,8 @@ test_that('available data is listed correctly with data_ignore', {
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
   test.df <- test.df[sort.df,]
 
-  override.config <- list(data_ignore = '*.csv', recursive_loading = TRUE)
-  expect_error(data.files <- list.data(override.config = override.config), NA)
+  expect_error(data.files <- list.data(data_ignore = '*.csv',
+                                       recursive_loading = TRUE), NA)
   expect_true(nrow(data.files) == 4)
   expect_equal(data.files$filename, test.df$filename)
   expect_equal(data.files$is_ignored, test.df$is_ignored)
@@ -307,9 +308,8 @@ test_that('available data is listed correctly with data_ignore', {
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
   test.df <- test.df[sort.df,]
 
-  override.config <- list(data_ignore = '/^\\w*\\.csv/',
-                          recursive_loading = TRUE)
-  expect_error(data.files <- list.data(override.config = override.config), NA)
+  expect_error(data.files <- list.data(data_ignore = '/^\\w*\\.csv/',
+                                       recursive_loading = TRUE), NA)
   expect_true(nrow(data.files) == 4)
   expect_equal(data.files$filename, test.df$filename)
   expect_equal(data.files$is_ignored, test.df$is_ignored)
@@ -338,9 +338,8 @@ test_that('available data is listed correctly with data_ignore', {
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
   test.df <- test.df[sort.df,]
 
-  override.config <- list(data_ignore = 'Thumbs.db, /^\\w*\\.csv/',
-                          recursive_loading = TRUE)
-  expect_error(data.files <- list.data(override.config = override.config), NA)
+  expect_error(data.files <- list.data(data_ignore = 'Thumbs.db, /^\\w*\\.csv/',
+                                       recursive_loading = TRUE), NA)
   expect_true(nrow(data.files) == 4)
   expect_equal(data.files$filename, test.df$filename)
   expect_equal(data.files$is_ignored, test.df$is_ignored)
@@ -370,9 +369,8 @@ test_that('available data is listed correctly with data_ignore', {
   sort.df <- order(test.df$cache_only, test.df$filename, test.df$varname)
   test.df <- test.df[sort.df,]
 
-  override.config <- list(data_ignore = 'Thumbs.db,,/^\\w*\\.csv/',
-                          recursive_loading = TRUE)
-  expect_error(data.files <- list.data(override.config = override.config), NA)
+  expect_error(data.files <- list.data(data_ignore = 'Thumbs.db,,/^\\w*\\.csv/',
+                                       recursive_loading = TRUE), NA)
   expect_true(nrow(data.files) == 4)
   expect_equal(data.files$filename, test.df$filename)
   expect_equal(data.files$is_ignored, test.df$is_ignored)
@@ -381,7 +379,7 @@ test_that('available data is listed correctly with data_ignore', {
 test_that('cached data is listed correctly as already cached', {
   # Create temporary project
   test_project <- tempfile('test_project')
-  suppressMessages(create.project(test_project, minimal = FALSE))
+  suppressMessages(create.project(test_project))
   on.exit(unlink(test_project, recursive = TRUE), add = TRUE)
 
   # Set temporary project as working directory
@@ -457,7 +455,7 @@ test_that('cached data is listed correctly as already cached', {
 test_that('cached data created during munging listed as cached only', {
   # Create temporary project
   test_project <- tempfile('test_project')
-  suppressMessages(create.project(test_project, minimal = FALSE))
+  suppressMessages(create.project(test_project))
   on.exit(unlink(test_project, recursive = TRUE), add = TRUE)
 
   # Set temporary project as working directory
